@@ -40,6 +40,8 @@ test_that("tune recipe only", {
   res_est <- collect_metrics(res)
   res_workflow <- res$.extracts[[1]]$.extracts[[1]]
 
+  expect_equal(res, .Last.tune.result)
+
   # Ensure tunable parameters in recipe are finalized
   num_comp <- res_workflow$pre$actions$recipe$recipe$steps[[2]]$num_comp
 
@@ -293,6 +295,8 @@ test_that("tune model only - failure in recipe is caught elegantly", {
       resamples = data_folds
     )
   })
+
+  expect_s3_class(cars_res, "iteration_results")
 })
 
 test_that("tune model only - failure in formula is caught elegantly", {
@@ -311,6 +315,8 @@ test_that("tune model only - failure in formula is caught elegantly", {
       control = control_bayes(extract = function(x) {1}, save_pred = TRUE)
     )
   })
+
+  expect_s3_class(cars_res, "iteration_results")
 })
 
 test_that("tune model and recipe - failure in recipe is caught elegantly", {
@@ -440,6 +446,7 @@ test_that("too few starting values", {
 
   expect_snapshot(tune:::check_bayes_initial_size(5, 3, FALSE))
   expect_snapshot(tune:::check_bayes_initial_size(5, 3, TRUE))
+  expect_snapshot(tune:::check_bayes_initial_size(2, 2, FALSE))
 
   expect_snapshot(error = TRUE, tune:::check_bayes_initial_size(5, 1, FALSE))
   expect_snapshot(error = TRUE, tune:::check_bayes_initial_size(5, 1, TRUE))
